@@ -19,7 +19,7 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.19.1"
+VERSION    = "2.19.2"
 LOCALEDIR = "/usr/local/share/locale"
 DATADIR    = "/usr/local/share"
 SYSCONFDIR = "/usr/local/etc"
@@ -52,8 +52,8 @@ DEFAULT_SHELL = "/bin/bash"
 NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
-XNEST_ARGV   = [ "/usr/X11R6/bin/Xnest", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
-SESSION_ARGV = [ "/etc/opt/gnome/gdm/Xsession", "" ]
+XNEST_ARGV   = [ "/usr/bin/Xnest", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
+SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
@@ -109,10 +109,13 @@ DIRECTORIES_TO_IGNORE = [
     ".gconf.xml.mandatory-alt",
     ".gconfd",
     ".gstreamer-0.8",
+    ".gstreamer-0.10",
     ".metacity/sessions",
     ".nautilus/metafiles",
     ".profile_cache",
     ".thumbnails",
+    ".wapi",
+    ".fontconfig"
     ".beagle"
 ]
 
